@@ -1,4 +1,4 @@
-#    $Id: Nominet.pm,v 1.12 2015/10/02 10:27:30 pete Exp $
+#    $Id: Nominet.pm,v 1.13 2015/11/04 16:23:31 pete Exp $
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.02_03';
+	our $VERSION = '0.02_04';
 }
 
 # file-scoped lexicals
@@ -174,12 +174,13 @@ sub new {
 
 	my $self = Net::EPP::Client->new(%params);
 	unless ($self->{timeout}) { $self->{timeout} = $params{timeout}; }
+	$self->{debug} = $Debug > 1 ? 1 : 0; # for parent
 
 	# Set the default years.
 	$self->{def_years} = 2;
 	if (defined $params{def_years}) {
 		my $years = scalar $params{def_years};
-		if ($years and $years =~ /^[0-9]+$/) {
+		if ($years =~ /^[0-9]+$/) {
 			if ($years > 0 and $years < 11) {
 				$self->{def_years} = $years;
 			} else {
@@ -974,7 +975,7 @@ sub modify_contact {
 	#   my $frame = $self->_generate_update_contact_frame($data);
 	# but it won't work because of present, but empty, add/rem/chg
 	# elements. Equally we cannot do this:
-    #   my $frame = Net::EPP::Frame::Command::Update::Contact->new;
+	#   my $frame = Net::EPP::Frame::Command::Update::Contact->new;
 	#   $frame->setContact ( $cont );
 	# so instead it needs this extra chunk of code which follows:
 
@@ -1303,7 +1304,7 @@ sub hello {
 		warn "Hello attempt while disconnected\n" if $Debug;
 		return undef;
 	}
-	my $frame = Net::EPP::Frame::Hello->new->toString;
+	my $frame = Net::EPP::Frame::Hello->new;
 
 	warn "Sending XML = \n" . $frame . "\n" if $Debug;
 	my $greeting = $self->request($frame);
